@@ -4,6 +4,7 @@ import os
 import socket
 import sys
 import uuid
+import warnings
 
 from future.standard_library import install_aliases
 
@@ -26,7 +27,7 @@ except ImportError:  # pragma: no cover
 
 __author__ = "Alex Laird"
 __copyright__ = "Copyright 2020, Alex Laird"
-__version__ = "4.1.16"
+__version__ = "4.2.2"
 
 logger = logging.getLogger(__name__)
 
@@ -155,7 +156,7 @@ def get_ngrok_process(pyngrok_config=None):
     return process.get_process(pyngrok_config)
 
 
-def connect(port="80", proto="http", name=None, options=None, pyngrok_config=None):
+def connect(port="80", proto="http", name=None, pyngrok_config=None, return_ngrok_tunnel=False, **options):
     """
     Establish a new ``ngrok`` tunnel for the given protocol to the given port, returning the connected
     public URL that tunnels to the local port.
@@ -173,14 +174,16 @@ def connect(port="80", proto="http", name=None, options=None, pyngrok_config=Non
     :type proto: str, optional
     :param name: A friendly name for the tunnel.
     :type name: str, optional
-    :param options: Parameters passed to `configuration for the ngrok
-        tunnel <https://ngrok.com/docs#tunnel-definitions>`_.
-    :type options: dict[str, str], optional
     :param pyngrok_config: The ``pyngrok`` configuration to use when interacting with the ``ngrok`` binary,
         defaults to ``conf.DEFAULT_PYNGROK_CONFIG`` (which can be overridden instead,
         `as shown here <index.html#config-file>`_).
     :type pyngrok_config: PyngrokConfig, optional
-    :return: The connected public URL.
+    :param return_ngrok_tunnel: ``True`` if a :class:`~pyngrok.ngrok.NgrokTunnel` should be returned, ``False`` for ``str``.
+    :type return_ngrok_tunnel: bool, optional
+    :param options: Remaining ``kwargs`` are passed as `configuration for the ngrok
+        tunnel <https://ngrok.com/docs#tunnel-definitions>`_.
+    :type options: dict, optional
+    :return: The connected public URL if ``return_ngrok_tunnel`` is ``False``, otherwise a :class:`~pyngrok.ngrok.NgrokTunnel`.
     :rtype: str
     """
     if options is None:
@@ -188,6 +191,12 @@ def connect(port="80", proto="http", name=None, options=None, pyngrok_config=Non
     if pyngrok_config is None:
         pyngrok_config = conf.DEFAULT_PYNGROK_CONFIG
 
+    if "options" in options:
+        warnings.warn(
+            "Support for passing \"options\" as a dict is deprecated and will be removed in 5.0.0, unpack the dict as kwargs",
+            DeprecationWarning, 2)
+        options.update(options.pop("options", {}))
+
     port = str(port)
     if not name:
         if not port.startswith("file://"):
@@ -211,9 +220,16 @@ def connect(port="80", proto="http", name=None, options=None, pyngrok_config=Non
                          pyngrok_config=pyngrok_config, api_url=api_url)
 
     if proto == "http" and not options.get("bind_tls", False):
-        tunnel.public_url = tunnel.public_url.replace("https", "http")
+        tunnel = NgrokTunnel(api_request("{}{}%20%28http%29".format(api_url, tunnel.uri), method="GET",
+                                         timeout=pyngrok_config.request_timeout),
+                             pyngrok_config, api_url)
 
-    return tunnel.public_url
+    if return_ngrok_tunnel:
+        return tunnel
+    else:
+        warnings.warn("Support for \"return_ngrok_tunnel\" as \"False\" is deprecated and will be removed in 5.0.0, "
+                      "when this method will return a NgrokTunnel instead of a str", DeprecationWarning, 2)
+        return tunnel.public_url
 
 
 def disconnect(public_url, pyngrok_config=None):
@@ -295,25 +311,6 @@ def kill(pyngrok_config=None):
     process.kill_process(pyngrok_config.ngrok_path)
 
 
-def get_version(pyngrok_config=None):
-    """
-    Get a tuple with the ``ngrok`` and ``pyngrok`` versions.
-
-    :param pyngrok_config: The ``pyngrok`` configuration to use when interacting with the ``ngrok`` binary,
-        defaults to ``conf.DEFAULT_PYNGROK_CONFIG`` (which can be overridden instead,
-        `as shown here <index.html#config-file>`_).
-    :type pyngrok_config: PyngrokConfig, optional
-    :return: A tuple of ``(ngrok_version, pyngrok_version)``.
-    :rtype: tuple
-    """
-    if pyngrok_config is None:
-        pyngrok_config = conf.DEFAULT_PYNGROK_CONFIG
-
-    ngrok_version = process.get_version(pyngrok_config.ngrok_path)
-
-    return ngrok_version, __version__
-
-
 def api_request(url, method="GET", data=None, params=None, timeout=4):
     """
     Invoke an API request to the given URL, returning JSON data from the response as a dict.
