@@ -28,7 +28,7 @@ except ImportError:  # pragma: no cover
 
 __author__ = "Alex Laird"
 __copyright__ = "Copyright 2020, Alex Laird"
-__version__ = "4.1.16"
+__version__ = "4.1.13"
 
 logger = logging.getLogger(__name__)
 ngrok_logger = logging.getLogger("{}.ngrok".format(__name__))
@@ -344,22 +344,6 @@ def _ensure_path_ready(ngrok_path):
         raise PyngrokNgrokError("ngrok is already running for the \"ngrok_path\": {}".format(ngrok_path))
 
 
-def get_version(ngrok_path):
-    """
-    Get the version of the given ``ngrok`` binary.
-
-    :param ngrok_path: The path to the ``ngrok`` binary.
-    :type ngrok_path: str
-    :return: A tuple of ``(ngrok_version, pyngrok_version)``.
-    :rtype: tuple
-    """
-    _ensure_path_ready(ngrok_path)
-
-    output = subprocess.check_output([ngrok_path, "--version"])
-
-    return output.decode("utf-8").split("version ")[1].strip()
-
-
 def _validate_config(config_path):
     with open(config_path, "r") as config_file:
         config = yaml.safe_load(config_file)
